# Security Policy

If you have discovered a security vulnerability in this project, please email us at info@starsim.org. Do not disclose it as a public issue. This gives us time to fix the issue before public exposure, reducing the chance that the exploit will be used before a patch is released.

Please provide the following information in your email:
- A description of the vulnerability and its impact
- How to reproduce the issue (if applicable)

Note that Starsim is built on underlying Python libraries that allow for arbitrary code execution. This is not a Starsim security vulnerability. Examples of vulnerabilities that we would address are:
1. Accidental inclusion of data that should not be publicly released
2. Malicious code in a script
3. Accidental overwriting of user files
4. Memory leaks causing serious system performance degradation

For the first two examples (private data and malicious code), we would appreciate an email. For the latter two examples, these would also count as bugs, so you can either email us or open an issue.

Thank you!
